Lemon Publications
==================

.. image:: https://secure.travis-ci.org/trilan/lemon-publications.png?branch=develop

``lemon-publications`` are some utils to create publications-like Django apps
(news, articles, etc.).
